==> pythonbible_parser-0.0.3.tar.gz: pythonbible_parser-0.0.3/README.md <==
# pythonbible-parser

A Python library for parsing Bible texts in various formats and convert them into a
format for easy and efficient use in Python.

[![PyPI version](https://img.shields.io/pypi/v/pythonbible-parser?color=blue&logo=pypi&logoColor=lightgray)](https://pypi.org/project/pythonbible-parser/)
[![license MIT](https://img.shields.io/badge/license-MIT-orange.svg)](https://opensource.org/licenses/MIT)

![Test](https://github.com/avendesora/pythonbible-parser/workflows/Test/badge.svg)
![CodeQL](https://github.com/avendesora/pythonbible-parser/workflows/CodeQL/badge.svg)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/8f7407c1b98040e185b81c945b78de22)](https://app.codacy.com/gh/avendesora/pythonbible-parser?utm_source=github.com&utm_medium=referral&utm_content=avendesora/pythonbible-parser&utm_campaign=Badge_Grade_Settings)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/8f7407c1b98040e185b81c945b78de22)](https://www.codacy.com/gh/avendesora/pythonbible-parser/dashboard?utm_source=github.com&utm_medium=referral&utm_content=avendesora/pythonbible-parser&utm_campaign=Badge_Coverage)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

[![Python 3.9](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9-blue?logo=python&logoColor=lightgray)](https://www.python.org/downloads/release/python-390/)

> **WARNING**: This is very much still a work in progress and does not yet have a 
> stable release. Breaking changes are expected.

## Installation

```shell script
pip install pythonbible-parser
```

==> pythonbible_parser-0.0.4.tar.gz: pythonbible_parser-0.0.4/README.md <==
# pythonbible-parser

A Python library for parsing Bible texts in various formats and convert them into a
format for easy and efficient use in Python.

[![PyPI version](https://img.shields.io/pypi/v/pythonbible-parser?color=blue&logo=pypi&logoColor=lightgray)](https://pypi.org/project/pythonbible-parser/)
[![license MIT](https://img.shields.io/badge/license-MIT-orange.svg)](https://opensource.org/licenses/MIT)

![Test](https://github.com/avendesora/pythonbible-parser/workflows/Test/badge.svg)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/8f7407c1b98040e185b81c945b78de22)](https://www.codacy.com/gh/avendesora/pythonbible-parser/dashboard?utm_source=github.com&utm_medium=referral&utm_content=avendesora/pythonbible-parser&utm_campaign=Badge_Coverage)

![CodeQL](https://github.com/avendesora/pythonbible-parser/workflows/CodeQL/badge.svg)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/8f7407c1b98040e185b81c945b78de22)](https://app.codacy.com/gh/avendesora/pythonbible-parser?utm_source=github.com&utm_medium=referral&utm_content=avendesora/pythonbible-parser&utm_campaign=Badge_Grade_Settings)

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/avendesora/pythonbible-parser/main.svg)](https://results.pre-commit.ci/latest/github/avendesora/pythonbible-parser/main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

[![Python 3.10](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20dev-blue?logo=python&logoColor=lightgray)](https://www.python.org/downloads/)

> **WARNING**: This is very much still a work in progress and does not yet have a
> stable release. Breaking changes are expected.

## Installation

```shell script
pip install pythonbible-parser
```
